"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

var _constants = require("./constants");

var _hooks = require("./hooks");

function wrapSet(app) {
  const wrappedSet = app.set.bind(app);

  app.set = (name, value) => {
    // eslint-disable-line no-param-reassign
    wrappedSet(name, value);
    app.emit((0, _constants.SETTING_CHANGED)(name), value);
  };
}

function useSetting(app, name, initialState) {
  const [state, setState] = (0, _react.useState)(() => {
    const currentValue = app.get(name);
    return currentValue === undefined ? typeof initialState === 'function' ? initialState() : initialState : currentValue;
  });
  (0, _react.useEffect)(() => {
    if (app.get(_constants.HAS_BEEN_WRAPPED)) {
      return;
    }

    app.set(_constants.HAS_BEEN_WRAPPED, true);
    wrapSet(app);
  }, [app]);
  (0, _hooks.useEventEmitter)(app, (0, _constants.SETTING_CHANGED)(name), setState);
  (0, _react.useDebugValue)(state);
  return [state, (0, _react.useCallback)(value => {
    app.set(name, value);
  }, [app, name])];
}

var _default = useSetting;
exports.default = _default;
//# sourceMappingURL=use-setting.js.map